======================
Django Hotsauce v0.5.1
======================

:Author: Etienne Robillard <tkadm30@yandex.ru>
:Version: 0.5.1
:Last modified: 2014-08-14

Welcome to the notmm toolkit developer's handbook! This is a work-in-progress
document and may contains errors and/or incompleted chapters, etc. You're
invited to send feedback or suggestions about this document.

Thanks for reading!

.. toctree::

    :maxdepth: 3

    handbook/getting-started
    handbook/customizing/advanced-configuration
    handbook/customizing/patching-django
    handbook/cheatsheet
    handbook/templates/mako


    reference/controllers/index
    reference/datastore
    reference/authentication
    reference/dbapi
    reference/urlmap

